@@ -1,67 +1,69 @@
 var languageNames = {
 "en-US": "Ingelesa (AEB)",
+"sq": "Albaniera",
 "am": "Amharera",
 "ar": "Arabiera",
 "ast": "Asturiera",
-"bg": "Bulgariera",
 "bn": "Bengaliera",
 "bn-IN": "Bengaliera (India)",
-"bo": "Tibetera",
 "bs": "Bosniera",
+"bg": "Bulgariera",
 "ca": "Katalana",
 "ca-valencia": "Katalana (Valentzia)",
+"zh-CN": "Txinera (soildua)",
+"zh-TW": "Txinera (tradizionala)",
+"hr": "Kroaziera",
 "cs": "Txekiera",
 "da": "Daniera",
-"de": "Alemana",
+"nl": "Nederlandera",
 "dz": "Dzongkha",
-"el": "Greziera",
 "en-GB": "Ingelesa (EB)",
 "en-ZA": "Ingelesa (HA)",
 "eo": "Esperantoa",
-"es": "Gaztelania",
 "et": "Estoniera",
 "eu": "Euskara",
 "fi": "Finlandiera",
 "fr": "Frantsesa",
 "gl": "Galiziera",
+"ka": "Georgiera",
+"de": "Alemana",
+"el": "Greziera",
 "gu": "Gujaratera",
 "he": "Hebreera",
 "hi": "Hindia",
-"hr": "Kroaziera",
 "hu": "Hungariera",
 "id": "Indonesiera",
 "is": "Islandiera",
 "it": "Italiera",
 "ja": "Japoniera",
-"ka": "Georgiera",
 "km": "Khmerera",
 "ko": "Koreera",
 "lo": "Laosera",
-"lt": "Lituaniera",
 "lv": "Letoniera",
+"lt": "Lituaniera",
 "mk": "Mazedoniera",
-"nb": "Norvegiera (Bokmål)",
 "ne": "Nepalera",
-"nl": "Nederlandera",
 "nn": "Norvegiera (Nynorsk)",
+"nb": "Norvegiera (Bokmål)",
 "om": "Oromoera",
 "pl": "Poloniera",
 "pt": "Portugesa",
 "pt-BR": "Portugesa (Brasil)",
 "ro": "Errumaniera",
 "ru": "Errusiera",
-"si": "Sinhalera",
 "sid": "Sidamoa",
+"si": "Sinhalera",
 "sk": "Eslovakiera",
 "sl": "Esloveniera",
-"sq": "Albaniera",
+"dsb": "Sorabiera (behekoa)",
+"hsb": "Sorabiera (goikoa)",
+"es": "Gaztelania",
 "sv": "Suediera",
-"ta": "Tamilera",
 "tg": "Tajikera",
+"ta": "Tamilera",
+"bo": "Tibetera",
 "tr": "Turkiera",
 "ug": "Uigurrera",
 "uk": "Ukrainiera",
 "vi": "Vietnamera",
-"zh-CN": "Txinera (soildua)",
-"zh-TW": "Txinera (tradizionala)",
 };
